==> spip_3.0.18.orig.tar.xz: spip/plugins-dist/urls_etendues/lang/urls_es.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/urls?lang_cible=es
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'actualiser_toutes' => 'Actualización de todas las URLs',
	'actualiser_toutes_explication' => 'Puede recalcular las URLs. Si una URL ha cambiado, se creará una nueva entrada (sin perder las URLS ya existentes y sin afectar a las URLs definidas manualmente).',

	// B
	'bouton_supprimer_url' => 'Suprimir esta URL',

	// E
	'erreur_arbo_2_segments_max' => 'No puedes utilizar más de dos segmentos de URL para un objeto',
	'erreur_config_url_forcee' => 'La configuración de las URLs está determinada en el archivo <tt>mes_options.php</tt>.',
	'explication_editer' => 'La gestión de URLs avanzada te permite editar la URL de las páginas de cada objeto editorial, y de gestionar el histórico de su evolución.',

	// I
	'icone_configurer_urls' => 'Configurar las URLs',
	'icone_controler_urls' => 'URLs significantes',
	'info_1_url' => '1 URL',
	'info_id_parent' => '#parent',
	'info_nb_urls' => '@nb@ URLs',
	'info_objet' => 'Objeto',

	// L
	'label_tri_date' => 'Fecha',
	'label_tri_id' => 'ID',
	'label_tri_url' => 'URL',
	'label_url' => 'Nueva URL',
	'label_url_minuscules_0' => 'Conservar las mayúsculas y minúsculas del título',
	'label_url_minuscules_1' => 'Forzar las URLs en minúsculas',
	'label_url_permanente' => 'Bloquear esta URL (no permitir actualizar luego de la edición del objeto)',
	'label_url_sep_id' => 'Caracter para separar el número agregado en caso de URLs duplicadas. ',
	'label_urls_activer_controle_oui' => 'Activar la gestión de URLs avanzada',
	'label_urls_nb_max_car' => 'Número maximo de caracteres',
	'label_urls_nb_min_car' => 'Número minimo de caracteres',
	'liberer_url' => 'Liberar',
	'liste_des_urls' => 'Todas las URLs',

	// T
	'texte_type_urls' => 'Abajo puedes elegir el modo de calcular la dirección de las páginas.',
	'texte_type_urls_attention' => 'Atención, este ajuste sólo funcionará si el fichero @htaccess@ está correctamente instalado en la raíz del sitio web.',
	'texte_urls_nb_max_car' => 'Si el título es más largo, será cortado.',
	'texte_urls_nb_min_car' => 'Si el título es más corto, será utilizado su número de identificador.',
	'titre_gestion_des_urls' => 'Gestión de URLs',
	'titre_type_arbo' => 'URLs Arborescentes',
	'titre_type_html' => 'URLs Objetos HTML',
	'titre_type_libres' => 'URLs Libres',
	'titre_type_page' => 'URLs Página',
	'titre_type_propres' => 'URLs Limpias',
	'titre_type_propres2' => 'URLs Limpias+<tt>.html</tt>',
	'titre_type_propres_qs' => 'URLs Limpias en query-string',
	'titre_type_simple' => 'URLs Simples',
	'titre_type_standard' => 'URLs Históricas',
	'titre_type_urls' => 'Tipo de direcciones URL',
	'tout_voir' => 'Ver todas las URLs',

	// U
	'url_ajout_impossible' => 'Se produjo un error. No fue posible guardar esta URL',
	'url_ajoutee' => 'La URL fue agregada',

	// V
	'verifier_url_nettoyee' => 'La URL fue corregida, puedes verificar antes de guardarla.',
	'verrouiller_url' => 'Bloquear'
);

?>

==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/urls_etendues/lang/urls_es.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/urls?lang_cible=es
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'actualiser_toutes' => 'Actualización de todas las URLs',
	'actualiser_toutes_explication' => 'Puede recalcular las URLs. Si una URL ha cambiado, se creará una nueva entrada (sin perder las URLS ya existentes y sin afectar a las URLs definidas manualmente.',

	// B
	'bouton_supprimer_url' => 'Suprimir esta URL',

	// E
	'erreur_arbo_2_segments_max' => 'No puedes utilizar más de dos segmentos de URL para un objeto',
	'erreur_config_url_forcee' => 'La configuración de las URLs está determinada en el archivo <tt>mes_options.php</tt>.',
	'explication_editer' => 'La gestión de URLs avanzada te permite editar la URL de las páginas de cada objeto editorial, y de gestionar el histórico de su evolución.',

	// I
	'icone_configurer_urls' => 'Configurar las URLs',
	'icone_controler_urls' => 'URLs significantes',
	'info_1_url' => '1 URL',
	'info_id_parent' => '#parent',
	'info_nb_urls' => '@nb@ URLs',
	'info_objet' => 'Objeto',

	// L
	'label_tri_date' => 'Fecha',
	'label_tri_id' => 'ID',
	'label_tri_url' => 'URL',
	'label_url' => 'Nueva URL',
	'label_url_minuscules_0' => 'Conservar las mayúsculas y minúsculas del título',
	'label_url_minuscules_1' => 'Forzar las URLs en minúsculas',
	'label_url_permanente' => 'Bloquear esta URL (no permitir actualizar luego de la edición del objeto)',
	'label_url_sep_id' => 'Caracter para separar el número agregado en caso de URLs duplicadas. ',
	'label_urls_activer_controle_oui' => 'Activar la gestión de URLs avanzada',
	'label_urls_nb_max_car' => 'Número maximo de caracteres',
	'label_urls_nb_min_car' => 'Número minimo de caracteres',
	'liberer_url' => 'Liberar',
	'liste_des_urls' => 'Todas las URLs',

	// T
	'texte_type_urls' => 'Abajo puedes elegir el modo de calcular la dirección de las páginas.',
	'texte_type_urls_attention' => 'Atención, este ajuste sólo funcionará si el fichero @htaccess@ está correctamente instalado en la raíz del sitio web.',
	'texte_urls_nb_max_car' => 'Si el título es más largo, será cortado.',
	'texte_urls_nb_min_car' => 'Si el título es más corto, será utilizado su número de identificador.',
	'titre_gestion_des_urls' => 'Gestión de URLs',
	'titre_type_arbo' => 'URLs Arborescentes',
	'titre_type_html' => 'URLs Objetos HTML',
	'titre_type_libres' => 'URLs Libres',
	'titre_type_page' => 'URLs Página',
	'titre_type_propres' => 'URLs Limpias',
	'titre_type_propres2' => 'URLs Limpias+<tt>.html</tt>',
	'titre_type_propres_qs' => 'URLs Limpias en query-string',
	'titre_type_simple' => 'URLs Simples',
	'titre_type_standard' => 'URLs Históricas',
	'titre_type_urls' => 'Tipo de direcciones URL',
	'tout_voir' => 'Ver todas las URLs',

	// U
	'url_ajout_impossible' => 'Se produjo un error. No fue posible guardar esta URL',
	'url_ajoutee' => 'La URL fue agregada',

	// V
	'verifier_url_nettoyee' => 'La URL fue corregida, puedes verificar antes de guardarla.',
	'verrouiller_url' => 'Bloquear'
);

?>
